@@ -1,9 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.4.3.  */
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2009, 2010 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -98,12 +97,14 @@
      AM_GLIB_GNU_GETTEXT = 315,
      AM_MAINTAINER_MODE = 316,
      AM_PROG_LIBTOOL = 317,
-     LT_INIT = 318,
-     LT_PREREQ = 319,
-     PKG_CHECK_MODULES = 320,
-     PKG_PROG_PKG_CONFIG = 321,
-     EMPTY = 322,
-     ARG = 323
+     AC_PROG_LIBTOOL = 318,
+     LT_INIT = 319,
+     DEFAULT_LT_INIT = 320,
+     LT_PREREQ = 321,
+     PKG_CHECK_MODULES = 322,
+     PKG_PROG_PKG_CONFIG = 323,
+     EMPTY = 324,
+     ARG = 325
    };
 #endif
 /* Tokens.  */
@@ -167,12 +168,14 @@
 #define AM_GLIB_GNU_GETTEXT 315
 #define AM_MAINTAINER_MODE 316
 #define AM_PROG_LIBTOOL 317
-#define LT_INIT 318
-#define LT_PREREQ 319
-#define PKG_CHECK_MODULES 320
-#define PKG_PROG_PKG_CONFIG 321
-#define EMPTY 322
-#define ARG 323
+#define AC_PROG_LIBTOOL 318
+#define LT_INIT 319
+#define DEFAULT_LT_INIT 320
+#define LT_PREREQ 321
+#define PKG_CHECK_MODULES 322
+#define PKG_PROG_PKG_CONFIG 323
+#define EMPTY 324
+#define ARG 325
 
 
 
